Name:           siril
Version:        0.9.6
Release:        1%{?dist}
Summary:        Astronomical image processing software

License:        GPLv3+
URL:            http://free-astro.org/index.php/Siril
Source0:        https://free-astro.org/download/%{name}-%{version}.tar.bz2

# Notes on dependencies:
# No gif support as giflib is too old in Fedora
# No ffmpeg and ffms support 

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  desktop-file-utils
BuildRequires:  intltool
BuildRequires:  libappstream-glib
BuildRequires:  pkgconfig(cfitsio)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libconfig)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libraw)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(opencv) 

%description
Siril is an image processing tool specially tailored for noise reduction and
improving the signal/noise ratio of an image from multiple captures, as
required in astronomy. Siril can align automatically or manually, stack and
enhance pictures from various file formats, even images sequences (movies and
SER files)

Note: This version is built without ffmpeg support due to Fedora software 
      guidelines.


%prep
%autosetup


%build
intltoolize -f -c
autoreconf -fi -Wno-portability
%configure
%make_build


%install
%make_install
install -Dm 644 platform-specific/linux/%{name}.xml %{buildroot}%{_datadir}/mime/packages/%{name}.xml
install -Dm 644 platform-specific/linux/org.free-astro.siril.appdata.xml %{buildroot}%{_datadir}/metainfo/org.free-astro.siril.appdata.xml

install -d %{buildroot}%{_datadir}/icons/
cp -r pixmaps/icons/* %{buildroot}%{_datadir}/icons/

desktop-file-install						\
	--dir=%{buildroot}%{_datadir}/applications		\
	platform-specific/linux/org.free-astro.siril.desktop

%find_lang %{name}


%check
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/org.free-astro.siril.appdata.xml


%post
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :
%if 0%{?fedora} < 24
update-desktop-database &> /dev/null || :
%endif

%postun
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi
%if 0%{?fedora} < 24
update-desktop-database &> /dev/null || :
%endif


%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files -f %{name}.lang
%license LICENSE COPYING
%doc AUTHORS ChangeLog LICENSE COPYING NEWS README.md
%{_bindir}/%{name}
%{_datadir}/applications/org.free-astro.siril.desktop
%{_datadir}/mime/packages/%{name}.xml
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/metainfo/org.free-astro.siril.appdata.xml
%{_datadir}/%{name}/
%{_mandir}/man1/%{name}.1*


%changelog
* Fri Jun 23 2017 Christian Dersch <lupinix@mailbox.org> - 0.9.6-1
- new version

* Thu Mar 02 2017 Christian Dersch <lupinix@mailbox.org> - 0.9.5-4
- rebuilt for opencv-3.2.0

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Dec 28 2016 Jon Ciesla <limburgher@gmail.com> - 0.9.5-2
- Rebuild for new LibRaw.

* Tue Nov 29 2016 Christian Dersch <lupinix@mailbox.org> - 0.9.5-1
- new version

* Fri Oct 14 2016 Christian Dersch <lupinix@mailbox.org> - 0.9.4-3
- Rebuilt

* Fri Oct 14 2016 Christian Dersch <lupinix@mailbox.org> - 0.9.4-2
- fix scriptlets, use update-desktop-database only for Fedora < 25

* Fri Oct 14 2016 Christian Dersch <lupinix@mailbox.org> - 0.9.4-1
- update to version 0.9.4
- complete rework of the package

* Fri Feb 05 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.8-21
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jun 19 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Aug 18 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8-19
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8-18
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed May 28 2014 Lubomir Rintel <lkundrak@v3.sk> - 0.8-17
- Fix format string security error
- Deal with the compile warnings
- Actually rebuild for the new cfitsio

* Fri Jan 10 2014 Orion Poplawski <orion@cora.nwra.com> - 0.8-16
- Rebuild for cfitsio 3.360

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8-15
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sat Mar 30 2013 Kevin Fenzi <kevin@scrye.com> - 0.8-14
- Rebuild for broken deps in rawhide

* Fri Feb 15 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8-12
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8-11
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Aug 3 2009 Lubomir Rintel <lkundrak@v3.sk> - 0.8-9
- Fix build
- Fix out of string bound writes (#494536)

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sat Apr 4 2009 Lubomir Rintel <lkundrak@v3.sk> - 0.8-7
- Fix crash on incorrectly loaded pictures (#494536)

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Aug 29 2008 Michael Schwendt <mschwendt@fedoraproject.org> - 0.8-5
- Include unowned directories

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.8-4
- Autorebuild for GCC 4.3

* Sat Nov 24 2007 Marek Mahut <mmahut@fedoraproject.org> - 0.8-3
- Initial build.
